@@ -1,8 +1,9 @@
+import re
 import inspect
 from pathlib import Path
 from typing import Dict, List, Optional, Tuple, Type, Sequence, Any
 
-from .utils import SQLParseException, SQLLoadException, VAR_REF, re
+from .utils import SQLParseException, SQLLoadException, VAR_REF, log
 from .types import QueryDatum, QueryDataTree, SQLOperationType, DriverAdapterProtocol
 
 # identifies name definition comments
@@ -32,6 +33,36 @@ _OP_TYPES = {
     "": SQLOperationType.SELECT,
 }
 
+# extracting comments requires some kind of scanner
+_UNCOMMENT = re.compile(
+    # single quote strings
+    r"(?P<squote>\'(\'\'|[^\'])*\')|"
+    # double quote strings
+    r'(?P<dquote>"(""|[^"])+")|'
+    # one-line comment
+    r"(?P<oneline>--.*?$)|"
+    # multi-line comment
+    r"(?P<multiline>/\*.*?\*/)",
+    re.DOTALL | re.MULTILINE,
+)
+
+
+def _remove_ml_comments(code: str) -> str:
+    """Remove /* ... */ comments from code"""
+    # identify commented regions
+    rm = []
+    for m in _UNCOMMENT.finditer(code):
+        ml = m.groupdict()["multiline"]
+        if ml:
+            rm.append(m.span())
+    # keep whatever else
+    ncode, current = "", 0
+    for start, end in rm:
+        ncode += code[current:start]
+        current = end
+    ncode += code[current:]
+    return ncode
+
 
 class QueryLoader:
     def __init__(
@@ -49,6 +80,8 @@ class QueryLoader:
         # - floc: file name and lineno the query was extracted from
         lines = [line.strip() for line in query.strip().splitlines()]
         qname, qop = self._get_name_op(lines[0])
+        if re.search(r"[^A-Za-z0-9_]", qname):
+            log.warning(f"non ASCII character in query name: {qname}")
         record_class = self._get_record_class(lines[1])
         sql, doc = self._get_sql_doc(lines[2 if record_class else 1 :])
         signature = self._build_signature(sql)
@@ -86,7 +119,7 @@ class QueryLoader:
         names = set()
         for match in VAR_REF.finditer(sql):
             gd = match.groupdict()
-            if gd["quote"] or gd["dblquote"]:
+            if gd["squote"] or gd["dquote"]:
                 continue
             name = gd["var_name"]
             if name.isdigit() or name in names:
@@ -103,7 +136,9 @@ class QueryLoader:
     def load_query_data_from_sql(
         self, sql: str, ns_parts: List[str] = [], fname: Optional[Path] = None
     ) -> List[QueryDatum]:
-        qdefs = _QUERY_DEF.split(sql)
+        usql = _remove_ml_comments(sql)
+        qdefs = _QUERY_DEF.split(usql)
+        # FIXME lineno is from the uncommented file
         lineno = 1 + qdefs[0].count("\n")
         data = []
         # first item is anything before the first query definition, drop it!
